@@ -53,7 +53,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCancelFlow(self, request):
-        """渠道版撤销签署流程接口，可以撤回：未全部签署完成；不可以撤回（终态）：已全部签署完成、已拒签、已过期、已撤回。
+        """撤销签署流程接口，可以撤回：未全部签署完成；不可以撤回（终态）：已全部签署完成、已拒签、已过期、已撤回。
         注意:
         能撤回合同的只能是合同的发起人或者发起企业的超管、法人
 
@@ -129,7 +129,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCreateBoundFlows(self, request):
-        """此接口（ChannelCreateBoundFlows）用于渠道子客领取合同，经办人需要有相应的角色，领取后的合同不能重复领取。
+        """此接口（ChannelCreateBoundFlows）用于子客领取合同，经办人需要有相应的角色，合同不能重复领取。
 
         :param request: Request instance for ChannelCreateBoundFlows.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateBoundFlowsRequest`
@@ -152,7 +152,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCreateConvertTaskApi(self, request):
-        """渠道创建文件转换任务
+        """创建文件转换任务
 
         :param request: Request instance for ChannelCreateConvertTaskApi.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateConvertTaskApiRequest`
@@ -174,8 +174,33 @@ class EssbasicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ChannelCreateEmbedWebUrl(self, request):
+        """本接口（ChannelCreateEmbedWebUrl）用于创建嵌入web的链接
+        本接口支持创建：创建印章，创建模版，修改模版，预览模版，预览合同流程的web链接
+        进入web连接后与当前控制台操作保持一致
+
+        :param request: Request instance for ChannelCreateEmbedWebUrl.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateEmbedWebUrlRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateEmbedWebUrlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChannelCreateEmbedWebUrl", params, headers=headers)
+            response = json.loads(body)
+            model = models.ChannelCreateEmbedWebUrlResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ChannelCreateFlowByFiles(self, request):
-        """接口（ChannelCreateFlowByFiles）用于渠道版通过文件创建签署流程。此接口静默签能力不可直接使用，需要运营申请
+        """接口（ChannelCreateFlowByFiles）用于通过文件创建签署流程。此接口静默签能力不可直接使用，请联系客户经理申请使用
 
         :param request: Request instance for ChannelCreateFlowByFiles.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateFlowByFilesRequest`
@@ -223,7 +248,7 @@ class EssbasicClient(AbstractClient):
     def ChannelCreateFlowReminds(self, request):
         """指定需要批量催办的签署流程Id，批量催办合同，最多100个；接口失败后返回错误信息
         注意:
-        该接口不可直接调用，请联系电子签运营开通后方可调用。
+        该接口不可直接调用，请联系客户经理申请使用
 
         :param request: Request instance for ChannelCreateFlowReminds.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateFlowRemindsRequest`
@@ -272,7 +297,10 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCreateFlowSignUrl(self, request):
-        """渠道版创建签署链接，需要联系运营人员开白后才可使用
+        """创建签署链接，请联系客户经理申请使用
+        该接口用于发起合同后，生成C端签署人的签署链接，点击跳转小程序完成签署
+        注意：该接口目前签署人类型仅支持个人签署方（PERSON）
+        注意：该接口可生成签署链接的C端签署人必须仅有手写签名和时间类型的签署控件
 
         :param request: Request instance for ChannelCreateFlowSignUrl.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateFlowSignUrlRequest`
@@ -318,8 +346,35 @@ class EssbasicClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ChannelCreatePrepareFlow(self, request):
+        """创建预发起合同
+        通过此接口指定：合同，签署人，填写控件信息，生成预创建合同链接，点击后跳转到web页面完成合同创建并发起
+        可指定合同信息不可更改，签署人信息不可更改
+        合同发起后，填写及签署流程与现有操作流程一致
+        注意：目前仅支持模版发起
+
+        :param request: Request instance for ChannelCreatePrepareFlow.
+        :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreatePrepareFlowRequest`
+        :rtype: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreatePrepareFlowResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ChannelCreatePrepareFlow", params, headers=headers)
+            response = json.loads(body)
+            model = models.ChannelCreatePrepareFlowResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ChannelCreateReleaseFlow(self, request):
-        """渠道版发起解除协议，主要应用场景为：基于一份已经签署的合同，进行解除操作。
+        """发起解除协议，主要应用场景为：基于一份已经签署的合同，进行解除操作。
         合同发起人必须在电子签已经进行实名。
 
         :param request: Request instance for ChannelCreateReleaseFlow.
@@ -343,7 +398,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCreateSealPolicy(self, request):
-        """将指定印章授权给企业下的某些员工
+        """将指定印章授权给第三方平台子客企业下的某些员工
 
         :param request: Request instance for ChannelCreateSealPolicy.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateSealPolicyRequest`
@@ -412,7 +467,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelDescribeOrganizationSeals(self, request):
-        """查询渠道子客企业电子印章，需要操作者具有管理印章权限
+        """查询子客企业电子印章，需要操作者具有管理印章权限
         客户指定需要获取的印章数量和偏移量，数量最多100，超过100按100处理；入参InfoType控制印章是否携带授权人信息，为1则携带，为0则返回的授权人信息为空数组。接口调用成功返回印章的信息列表还有企业印章的总数。
 
         :param request: Request instance for ChannelDescribeOrganizationSeals.
@@ -436,7 +491,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelGetTaskResultApi(self, request):
-        """渠道版查询转换任务状态
+        """查询转换任务状态
 
         :param request: Request instance for ChannelGetTaskResultApi.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelGetTaskResultApiRequest`
@@ -459,7 +514,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelUpdateSealStatus(self, request):
-        """本接口（ChannelUpdateSealStatus）由于渠道版更新印章状态
+        """本接口（ChannelUpdateSealStatus）用于第三方应用平台为子客企业更新印章状态
 
         :param request: Request instance for ChannelUpdateSealStatus.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelUpdateSealStatusRequest`
@@ -529,7 +584,7 @@ class EssbasicClient(AbstractClient):
 
 
     def CreateConsoleLoginUrl(self, request):
-        """此接口（CreateConsoleLoginUrl）用于创建渠道子客企业控制台Web/移动登录链接。登录链接是子客控制台的唯一入口。
+        """此接口（CreateConsoleLoginUrl）用于创建第三方平台子客企业控制台Web/移动登录链接。登录链接是子客控制台的唯一入口。
         若子客企业未激活，会进入企业激活流程，首次参与激活流程的经办人会成为超管。（若企业激活过程中填写信息有误，需要重置激活流程，可以换一个经办人OpenId获取新的链接进入。）
         若子客企业已激活，使用了新的经办人OpenId进入，则会进入经办人的实名流程。
         若子客企业、经办人均已完成认证，则会直接进入子客Web控制台。
@@ -580,7 +635,7 @@ class EssbasicClient(AbstractClient):
 
 
     def CreateSealByImage(self, request):
-        """渠道通过图片为子客代创建印章，图片最大5MB
+        """通过图片为子客企业代创建印章，图片最大5MB
 
         :param request: Request instance for CreateSealByImage.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateSealByImageRequest`
@@ -608,9 +663,17 @@ class EssbasicClient(AbstractClient):
         跳转小程序的几种方式：主要是设置不同的EndPoint
         1. 通过链接Url直接跳转到小程序，不需要返回
         设置EndPoint为WEIXINAPP，得到链接打开即可。（与短信提醒用户签署形式一样）。
+
         2. 通过链接Url打开H5引导页-->点击跳转到小程序-->签署完退出小程序-->回到H5引导页-->跳转到指定JumpUrl
         设置EndPoint为CHANNEL，指定JumpUrl，得到链接打开即可。
+
         3. 客户App直接跳转到小程序-->小程序签署完成-->返回App
+        跳转到小程序的实现，参考官方文档
+        https://developers.weixin.qq.com/miniprogram/dev/framework/open-ability/launchApp.html
+        其中小程序的原始Id，请联系<对接技术人员>获取，或者查看小程序信息自助获取。
+        使用CreateSignUrls，设置EndPoint为APP，得到path。
+
+        4. 客户小程序直接跳到电子签小程序-->签署完成退出电子签小程序-->回到客户小程序
         跳转到小程序的实现，参考官方文档（分为全屏、半屏两种方式）
         全屏方式：
         （https://developers.weixin.qq.com/miniprogram/dev/api/navigate/wx.navigateToMiniProgram.html）
@@ -618,8 +681,6 @@ class EssbasicClient(AbstractClient):
         （https://developers.weixin.qq.com/miniprogram/dev/framework/open-ability/openEmbeddedMiniProgram.html）
         其中小程序的原始Id，请联系<对接技术人员>获取，或者查看小程序信息自助获取。
         使用CreateSignUrls，设置EndPoint为APP，得到path。
-        4. 客户小程序直接跳到电子签小程序-->签署完成退出电子签小程序-->回到客户小程序
-        实现方式同App跳小程序。
 
         :param request: Request instance for CreateSignUrls.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateSignUrlsRequest`
@@ -735,7 +796,7 @@ class EssbasicClient(AbstractClient):
 
 
     def DescribeTemplates(self, request):
-        """通过此接口（DescribeTemplates）查询该子客企业在电子签拥有的有效模板，不包括渠道模板
+        """通过此接口（DescribeTemplates）查询该第三方平台子客企业在电子签拥有的有效模板，不包括第三方平台模板
 
         :param request: Request instance for DescribeTemplates.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.DescribeTemplatesRequest`
@@ -758,7 +819,7 @@ class EssbasicClient(AbstractClient):
 
 
     def DescribeUsage(self, request):
-        """此接口（DescribeUsage）用于获取渠道所有合作企业流量消耗情况。
+        """此接口（DescribeUsage）用于获取第三方平台所有合作企业流量消耗情况。
          注: 此接口每日限频2次，若要扩大限制次数,请提前与客服经理或邮件至e-contract@tencent.com进行联系。
 
         :param request: Request instance for DescribeUsage.
@@ -829,9 +890,9 @@ class EssbasicClient(AbstractClient):
 
 
     def OperateChannelTemplate(self, request):
-        """此接口（OperateChannelTemplate）用于针对渠道模板库中的模板对子客企业可见性的查询和设置，不会直接分配渠道模板给子客企业。
+        """此接口（OperateChannelTemplate）用于针对第三方应用平台模板库中的模板对子客企业可见性的查询和设置，不会直接分配第三方应用平台模板给子客企业。
         1、OperateType=select时：
-        查询渠道模板库
+        查询第三方应用平台模板库
         2、OperateType=update或者delete时：
         对子客企业进行模板库中模板可见性的修改、删除操作。
 
@@ -881,7 +942,7 @@ class EssbasicClient(AbstractClient):
 
 
     def SyncProxyOrganization(self, request):
-        """此接口（SyncProxyOrganization）用于同步渠道子客企业信息，主要是子客企业的营业执照，便于子客企业开通过程中不用手动上传。若有需要调用此接口，需要在创建控制链接CreateConsoleLoginUrl之后即刻进行调用。
+        """此接口（SyncProxyOrganization）用于同步第三方平台子客企业信息，主要是子客企业的营业执照，便于子客企业开通过程中不用手动上传。若有需要调用此接口，需要在创建控制链接CreateConsoleLoginUrl之后即刻进行调用。
 
         :param request: Request instance for SyncProxyOrganization.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.SyncProxyOrganizationRequest`
@@ -904,7 +965,7 @@ class EssbasicClient(AbstractClient):
 
 
     def SyncProxyOrganizationOperators(self, request):
-        """此接口（SyncProxyOrganizationOperators）用于同步渠道子客企业经办人列表，主要是同步经办人的离职状态。子客Web控制台的组织架构管理，是依赖于渠道平台的，无法针对员工做新增/更新/离职等操作。
+        """此接口（SyncProxyOrganizationOperators）用于同步 第三方平台子客企业经办人列表，主要是同步经办人的离职状态。子客Web控制台的组织架构管理，是依赖于第三方应用平台的，无法针对员工做新增/更新/离职等操作。
         若经办人信息有误，或者需要修改，也可以先将之前的经办人做离职操作，然后重新使用控制台链接CreateConsoleLoginUrl让经办人重新实名。
 
         :param request: Request instance for SyncProxyOrganizationOperators.
@@ -929,6 +990,7 @@ class EssbasicClient(AbstractClient):
 
     def UploadFiles(self, request):
         """此接口（UploadFiles）用于文件上传。
+        其中上传的文件，图片类型(png/jpg/jpeg)大小限制为5M，其他大小限制为60M。
         调用时需要设置Domain, 正式环境为 file.ess.tencent.cn。
         代码示例：
         HttpProfile httpProfile = new HttpProfile();
